diff decoders/raw.c @ 47:ea58bc3b15d7

Added init() and quit() methods.
author Ryan C. Gordon <icculus@icculus.org>
date Sat, 22 Sep 2001 14:41:38 +0000
parents 29313c20963d
children b13fafb976be
line wrap: on
line diff
--- a/decoders/raw.c	Sat Sep 22 14:41:10 2001 +0000
+++ b/decoders/raw.c	Sat Sep 22 14:41:38 2001 +0000
@@ -52,6 +52,8 @@
 #endif
 
 
+static int RAW_init(void);
+static void RAW_quit(void);
 static int RAW_open(Sound_Sample *sample, const char *ext);
 static void RAW_close(Sound_Sample *sample);
 static Uint32 RAW_read(Sound_Sample *sample);
@@ -65,12 +67,26 @@
         "http://www.icculus.org/SDL_sound/"
     },
 
-    RAW_open,       /* open() method       */
-    RAW_close,      /* close() method       */
-    RAW_read        /* read() method       */
+    RAW_init,       /*  init() method */
+    RAW_quit,       /*  quit() method */
+    RAW_open,       /*  open() method */
+    RAW_close,      /* close() method */
+    RAW_read        /*  read() method */
 };
 
 
+static int RAW_init(void)
+{
+    return(1);  /* always succeeds. */
+} /* RAW_init */
+
+
+static void RAW_quit(void)
+{
+    /* it's a no-op. */
+} /* RAW_quit */
+
+
 static int RAW_open(Sound_Sample *sample, const char *ext)
 {
         /*